field

package
v0.0.2-0...-db6250e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 17, 2020 License: CC0-1.0, CC0-1.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Product

func Product(F Interface, S ...object.Element) (object.Element, error)

Product returns the product of the elements in the slice S. The product of the empty slice is one. If F satisfies the interface:

type Producter interface {
	Product(S ...object.Element) (object.Element, error) // Product
	   returns the product of the elements in the slice S. The product
	   of the empty slice is one.
}

then F's Product method will be called.

func Sum

func Sum(F Interface, S ...object.Element) (object.Element, error)

Sum returns the sum of the elements in the slice S. The sum of the empty slice is the zero element. If F satisfies the interface:

type Sumer interface {
	Sum(S ...object.Element) (object.Element, error) // Sum returns
	   the sum of the elements in the slice S. The sum of the empty
	   slice is the zero element.
}

then F's Sum method will be called.

Types

type Interface

type Interface interface {
	ring.Interface
	ring.IsUniter
	Inverse(x object.Element) (object.Element, error)                  // Inverse returns the inverse x^-1 of x.
	Divide(x object.Element, y object.Element) (object.Element, error) // Divide returns the division x / y
}

Interface defines the field interface that all fields must satisfy.

Jump to