Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Sum ¶
Sum return the sum x1 + ... + xn. The sum of the empty sequence is zero. If M satisfies the interface:
type Sumer interface {
Sum(S ...object.Element) (object.Element, error) // Sum returns
the sum of the elements in the slice S. The sum of the empty
slice is the zero element.
}
then M's Sum method will be called.
Types ¶
type Interface ¶
type Interface interface {
abeliangroup.Interface
Scalable
}
Interface defines the module interface that all modules must satisfy.
type Scalable ¶
type Scalable interface {
ScalarMultiply(a object.Element, x object.Element) (object.Element, error) // ScalarMultiply returns the scalar product a * x, where a is an element of the ring, and x is an element of the module.
ScalarRing() ring.Interface // ScalarRing returns the scalar ring.
}
Scalable defines the ScalarMultiply and ScalarRing methods.
Click to show internal directories.
Click to hide internal directories.