Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Product ¶
Product returns the product of the elements in the slice S. The product of the empty slice is one. If F satisfies the interface:
type Producter interface {
Product(S ...object.Element) (object.Element, error) // Product
returns the product of the elements in the slice S. The product
of the empty slice is one.
}
then F's Product method will be called.
func Sum ¶
Sum returns the sum of the elements in the slice S. The sum of the empty slice is the zero element. If F satisfies the interface:
type Sumer interface {
Sum(S ...object.Element) (object.Element, error) // Sum returns
the sum of the elements in the slice S. The sum of the empty
slice is the zero element.
}
then F's Sum method will be called.
Types ¶
type Interface ¶
type Interface interface {
ring.Interface
ring.IsUniter
Inverse(x object.Element) (object.Element, error) // Inverse returns the inverse x^-1 of x.
Divide(x object.Element, y object.Element) (object.Element, error) // Divide returns the division x / y
}
Interface defines the field interface that all fields must satisfy.
Click to show internal directories.
Click to hide internal directories.